@@ -3,6 +3,7 @@
 from __future__ import absolute_import
 
 from wallee.api.account_service_api import AccountServiceApi
+from wallee.api.analytics_query_service_api import AnalyticsQueryServiceApi
 from wallee.api.application_user_service_api import ApplicationUserServiceApi
 from wallee.api.bank_account_service_api import BankAccountServiceApi
 from wallee.api.bank_transaction_service_api import BankTransactionServiceApi
@@ -34,6 +35,9 @@ from wallee.api.installment_plan_calculation_service_api import InstallmentPlanC
 from wallee.api.installment_plan_configuration_service_api import InstallmentPlanConfigurationServiceApi
 from wallee.api.installment_plan_slice_configuration_service_api import InstallmentPlanSliceConfigurationServiceApi
 from wallee.api.internal_transfer_bank_transaction_service_api import InternalTransferBankTransactionServiceApi
+from wallee.api.invoice_reconciliation_record_invoice_link_service_api import InvoiceReconciliationRecordInvoiceLinkServiceApi
+from wallee.api.invoice_reconciliation_record_service_api import InvoiceReconciliationRecordServiceApi
+from wallee.api.invoice_reimbursement_service_api import InvoiceReimbursementServiceApi
 from wallee.api.label_description_group_service_api import LabelDescriptionGroupServiceApi
 from wallee.api.label_description_service_api import LabelDescriptionServiceApi
 from wallee.api.language_service_api import LanguageServiceApi
@@ -50,6 +54,8 @@ from wallee.api.payment_processor_configuration_service_api import PaymentProces
 from wallee.api.payment_processor_service_api import PaymentProcessorServiceApi
 from wallee.api.payment_terminal_service_api import PaymentTerminalServiceApi
 from wallee.api.payment_terminal_till_service_api import PaymentTerminalTillServiceApi
+from wallee.api.payment_terminal_transaction_summary_service_api import PaymentTerminalTransactionSummaryServiceApi
+from wallee.api.payment_web_app_service_api import PaymentWebAppServiceApi
 from wallee.api.permission_service_api import PermissionServiceApi
 from wallee.api.refund_bank_transaction_service_api import RefundBankTransactionServiceApi
 from wallee.api.refund_comment_service_api import RefundCommentServiceApi
@@ -134,6 +140,12 @@ from wallee.models.account_state import AccountState
 from wallee.models.account_type import AccountType
 from wallee.models.address import Address
 from wallee.models.address_create import AddressCreate
+from wallee.models.analytics_query import AnalyticsQuery
+from wallee.models.analytics_query_execution import AnalyticsQueryExecution
+from wallee.models.analytics_query_execution_state import AnalyticsQueryExecutionState
+from wallee.models.analytics_query_result_batch import AnalyticsQueryResultBatch
+from wallee.models.analytics_schema_column import AnalyticsSchemaColumn
+from wallee.models.analytics_schema_table import AnalyticsSchemaTable
 from wallee.models.authenticated_card_data_create import AuthenticatedCardDataCreate
 from wallee.models.bank_account import BankAccount
 from wallee.models.bank_account_environment import BankAccountEnvironment
@@ -219,6 +231,12 @@ from wallee.models.installment_payment_state import InstallmentPaymentState
 from wallee.models.installment_plan_configuration import InstallmentPlanConfiguration
 from wallee.models.installment_plan_slice_configuration import InstallmentPlanSliceConfiguration
 from wallee.models.internal_transfer_bank_transaction import InternalTransferBankTransaction
+from wallee.models.invoice_reconciliation_record_invoice_link import InvoiceReconciliationRecordInvoiceLink
+from wallee.models.invoice_reconciliation_record_rejection_status import InvoiceReconciliationRecordRejectionStatus
+from wallee.models.invoice_reconciliation_record_state import InvoiceReconciliationRecordState
+from wallee.models.invoice_reconciliation_record_type import InvoiceReconciliationRecordType
+from wallee.models.invoice_reimbursement import InvoiceReimbursement
+from wallee.models.invoice_reimbursement_state import InvoiceReimbursementState
 from wallee.models.label import Label
 from wallee.models.label_descriptor import LabelDescriptor
 from wallee.models.label_descriptor_category import LabelDescriptorCategory
@@ -242,6 +260,24 @@ from wallee.models.metric_usage import MetricUsage
 from wallee.models.one_click_payment_mode import OneClickPaymentMode
 from wallee.models.payment_adjustment import PaymentAdjustment
 from wallee.models.payment_adjustment_type import PaymentAdjustmentType
+from wallee.models.payment_app_charge_attempt_target_state import PaymentAppChargeAttemptTargetState
+from wallee.models.payment_app_charge_attempt_update_request import PaymentAppChargeAttemptUpdateRequest
+from wallee.models.payment_app_completion_configuration import PaymentAppCompletionConfiguration
+from wallee.models.payment_app_completion_configuration_create import PaymentAppCompletionConfigurationCreate
+from wallee.models.payment_app_completion_target_state import PaymentAppCompletionTargetState
+from wallee.models.payment_app_completion_update_request import PaymentAppCompletionUpdateRequest
+from wallee.models.payment_app_connector import PaymentAppConnector
+from wallee.models.payment_app_connector_creation_request import PaymentAppConnectorCreationRequest
+from wallee.models.payment_app_connector_state import PaymentAppConnectorState
+from wallee.models.payment_app_processor import PaymentAppProcessor
+from wallee.models.payment_app_processor_creation_request import PaymentAppProcessorCreationRequest
+from wallee.models.payment_app_processor_state import PaymentAppProcessorState
+from wallee.models.payment_app_refund_configuration import PaymentAppRefundConfiguration
+from wallee.models.payment_app_refund_configuration_create import PaymentAppRefundConfigurationCreate
+from wallee.models.payment_app_refund_target_state import PaymentAppRefundTargetState
+from wallee.models.payment_app_refund_update_request import PaymentAppRefundUpdateRequest
+from wallee.models.payment_app_void_target_state import PaymentAppVoidTargetState
+from wallee.models.payment_app_void_update_request import PaymentAppVoidUpdateRequest
 from wallee.models.payment_connector import PaymentConnector
 from wallee.models.payment_connector_configuration import PaymentConnectorConfiguration
 from wallee.models.payment_connector_feature import PaymentConnectorFeature
@@ -250,6 +286,8 @@ from wallee.models.payment_contract_state import PaymentContractState
 from wallee.models.payment_contract_type import PaymentContractType
 from wallee.models.payment_information_hash import PaymentInformationHash
 from wallee.models.payment_information_hash_type import PaymentInformationHashType
+from wallee.models.payment_initiation_advice_file import PaymentInitiationAdviceFile
+from wallee.models.payment_initiation_advice_file_state import PaymentInitiationAdviceFileState
 from wallee.models.payment_link import PaymentLink
 from wallee.models.payment_link_address_handling_mode import PaymentLinkAddressHandlingMode
 from wallee.models.payment_link_protection_mode import PaymentLinkProtectionMode
@@ -266,12 +304,16 @@ from wallee.models.payment_terminal_configuration import PaymentTerminalConfigur
 from wallee.models.payment_terminal_configuration_state import PaymentTerminalConfigurationState
 from wallee.models.payment_terminal_configuration_version import PaymentTerminalConfigurationVersion
 from wallee.models.payment_terminal_configuration_version_state import PaymentTerminalConfigurationVersionState
+from wallee.models.payment_terminal_dcc_transaction_sum import PaymentTerminalDccTransactionSum
 from wallee.models.payment_terminal_location import PaymentTerminalLocation
 from wallee.models.payment_terminal_location_state import PaymentTerminalLocationState
 from wallee.models.payment_terminal_location_version import PaymentTerminalLocationVersion
 from wallee.models.payment_terminal_location_version_state import PaymentTerminalLocationVersionState
 from wallee.models.payment_terminal_receipt_type import PaymentTerminalReceiptType
 from wallee.models.payment_terminal_state import PaymentTerminalState
+from wallee.models.payment_terminal_transaction_sum import PaymentTerminalTransactionSum
+from wallee.models.payment_terminal_transaction_summary import PaymentTerminalTransactionSummary
+from wallee.models.payment_terminal_transaction_summary_fetch_request import PaymentTerminalTransactionSummaryFetchRequest
 from wallee.models.payment_terminal_type import PaymentTerminalType
 from wallee.models.permission import Permission
 from wallee.models.persistable_currency_amount import PersistableCurrencyAmount
@@ -294,6 +336,7 @@ from wallee.models.refund_state import RefundState
 from wallee.models.refund_type import RefundType
 from wallee.models.rendered_document import RenderedDocument
 from wallee.models.rendered_terminal_receipt import RenderedTerminalReceipt
+from wallee.models.rendered_terminal_transaction_summary import RenderedTerminalTransactionSummary
 from wallee.models.resource_path import ResourcePath
 from wallee.models.resource_state import ResourceState
 from wallee.models.rest_address_format import RestAddressFormat
@@ -425,7 +468,6 @@ from wallee.models.transaction_group_state import TransactionGroupState
 from wallee.models.transaction_invoice_comment import TransactionInvoiceComment
 from wallee.models.transaction_invoice_replacement import TransactionInvoiceReplacement
 from wallee.models.transaction_invoice_state import TransactionInvoiceState
-from wallee.models.transaction_line_item_update_request import TransactionLineItemUpdateRequest
 from wallee.models.transaction_line_item_version_create import TransactionLineItemVersionCreate
 from wallee.models.transaction_line_item_version_state import TransactionLineItemVersionState
 from wallee.models.transaction_state import TransactionState
@@ -467,6 +509,8 @@ from wallee.models.delivery_indication import DeliveryIndication
 from wallee.models.human_user_create import HumanUserCreate
 from wallee.models.human_user_update import HumanUserUpdate
 from wallee.models.installment_payment_slice import InstallmentPaymentSlice
+from wallee.models.invoice_reconciliation_record import InvoiceReconciliationRecord
+from wallee.models.invoice_reimbursement_with_refund_reference import InvoiceReimbursementWithRefundReference
 from wallee.models.payment_link_active import PaymentLinkActive
 from wallee.models.payment_link_create import PaymentLinkCreate
 from wallee.models.refund_bank_transaction import RefundBankTransaction
